@@ -36,12 +36,15 @@ use base qw{ PPIx::Regexp::Token::Reference };
 
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{
-    MINIMUM_PERL RE_CAPTURE_NAME
-    TOKEN_LITERAL TOKEN_UNKNOWN
+    MINIMUM_PERL
+    RE_CAPTURE_NAME
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+    @CARP_NOT
 };
 use PPIx::Regexp::Util qw{ __to_ordinal_en };
 
-our $VERSION = '0.055';
+our $VERSION = '0.064';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -85,8 +88,8 @@ my @external = (	# Recognition used externally
 my @recognize_regexp = (	# recognition used internally
     [
 	qr{ \A \\ (?:		# numbered (including relative)
-	    ( \d+ )	|
-	    g (?: ( -? \d+ ) | \{ ( -? \d+ ) \} )
+	    ( [0-9]+ )	|
+	    g (?: ( -? [0-9]+ ) | \{ ( -? [0-9]+ ) \} )
 	)
 	}smx, { is_named => 0 }, ],
     [
@@ -101,7 +104,7 @@ my @recognize_regexp = (	# recognition used internally
 my %recognize = (
     regexp	=> \@recognize_regexp,
     repl	=> [
-	[ qr{ \A \\ ( \d+ ) }smx, { is_named => 0 } ],
+	[ qr{ \A \\ ( [0-9]+ ) }smx, { is_named => 0 } ],
     ],
 );
 
@@ -210,7 +213,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2018 by Thomas R. Wyant, III
+Copyright (C) 2009-2019 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
